@@ -1,4 +1,12 @@
-"Main interface for backup service type defs"
+"""
+Main interface for backup service type definitions.
+
+Usage::
+
+    from mypy_boto3.backup.type_defs import LifecycleTypeDef
+
+    data: LifecycleTypeDef = {...}
+"""
 from datetime import datetime
 import sys
 from typing import Dict, List
@@ -13,10 +21,81 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "LifecycleTypeDef",
+    "CopyActionTypeDef",
+    "BackupRuleInputTypeDef",
+    "BackupPlanInputTypeDef",
+    "ConditionTypeDef",
+    "BackupSelectionTypeDef",
+    "CreateBackupPlanOutputTypeDef",
+    "CreateBackupSelectionOutputTypeDef",
+    "CreateBackupVaultOutputTypeDef",
+    "DeleteBackupPlanOutputTypeDef",
+    "RecoveryPointCreatorTypeDef",
+    "DescribeBackupJobOutputTypeDef",
+    "DescribeBackupVaultOutputTypeDef",
+    "CopyJobTypeDef",
+    "DescribeCopyJobOutputTypeDef",
+    "DescribeProtectedResourceOutputTypeDef",
+    "CalculatedLifecycleTypeDef",
+    "DescribeRecoveryPointOutputTypeDef",
+    "DescribeRestoreJobOutputTypeDef",
+    "ExportBackupPlanTemplateOutputTypeDef",
+    "BackupRuleTypeDef",
+    "BackupPlanTypeDef",
+    "GetBackupPlanFromJSONOutputTypeDef",
+    "GetBackupPlanFromTemplateOutputTypeDef",
+    "GetBackupPlanOutputTypeDef",
+    "GetBackupSelectionOutputTypeDef",
+    "GetBackupVaultAccessPolicyOutputTypeDef",
+    "GetBackupVaultNotificationsOutputTypeDef",
+    "GetRecoveryPointRestoreMetadataOutputTypeDef",
+    "GetSupportedResourceTypesOutputTypeDef",
+    "BackupJobTypeDef",
+    "ListBackupJobsOutputTypeDef",
+    "BackupPlanTemplatesListMemberTypeDef",
+    "ListBackupPlanTemplatesOutputTypeDef",
+    "BackupPlansListMemberTypeDef",
+    "ListBackupPlanVersionsOutputTypeDef",
+    "ListBackupPlansOutputTypeDef",
+    "BackupSelectionsListMemberTypeDef",
+    "ListBackupSelectionsOutputTypeDef",
+    "BackupVaultListMemberTypeDef",
+    "ListBackupVaultsOutputTypeDef",
+    "ListCopyJobsOutputTypeDef",
+    "ProtectedResourceTypeDef",
+    "ListProtectedResourcesOutputTypeDef",
+    "RecoveryPointByBackupVaultTypeDef",
+    "ListRecoveryPointsByBackupVaultOutputTypeDef",
+    "RecoveryPointByResourceTypeDef",
+    "ListRecoveryPointsByResourceOutputTypeDef",
+    "RestoreJobsListMemberTypeDef",
+    "ListRestoreJobsOutputTypeDef",
+    "ListTagsOutputTypeDef",
+    "StartBackupJobOutputTypeDef",
+    "StartCopyJobOutputTypeDef",
+    "StartRestoreJobOutputTypeDef",
+    "UpdateBackupPlanOutputTypeDef",
+    "UpdateRecoveryPointLifecycleOutputTypeDef",
+)
+
 LifecycleTypeDef = TypedDict(
     "LifecycleTypeDef", {"MoveToColdStorageAfterDays": int, "DeleteAfterDays": int}, total=False
 )
 
+_RequiredCopyActionTypeDef = TypedDict(
+    "_RequiredCopyActionTypeDef", {"DestinationBackupVaultArn": str}
+)
+_OptionalCopyActionTypeDef = TypedDict(
+    "_OptionalCopyActionTypeDef", {"Lifecycle": LifecycleTypeDef}, total=False
+)
+
+
+class CopyActionTypeDef(_RequiredCopyActionTypeDef, _OptionalCopyActionTypeDef):
+    pass
+
+
 _RequiredBackupRuleInputTypeDef = TypedDict(
     "_RequiredBackupRuleInputTypeDef", {"RuleName": str, "TargetBackupVaultName": str}
 )
@@ -28,6 +107,7 @@ _OptionalBackupRuleInputTypeDef = TypedDict(
         "CompletionWindowMinutes": int,
         "Lifecycle": LifecycleTypeDef,
         "RecoveryPointTags": Dict[str, str],
+        "CopyActions": List[CopyActionTypeDef],
     },
     total=False,
 )
@@ -129,6 +209,31 @@ DescribeBackupVaultOutputTypeDef = TypedDict(
     total=False,
 )
 
+CopyJobTypeDef = TypedDict(
+    "CopyJobTypeDef",
+    {
+        "CopyJobId": str,
+        "SourceBackupVaultArn": str,
+        "SourceRecoveryPointArn": str,
+        "DestinationBackupVaultArn": str,
+        "DestinationRecoveryPointArn": str,
+        "ResourceArn": str,
+        "CreationDate": datetime,
+        "CompletionDate": datetime,
+        "State": Literal["CREATED", "RUNNING", "COMPLETED", "FAILED"],
+        "StatusMessage": str,
+        "BackupSizeInBytes": int,
+        "IamRoleArn": str,
+        "CreatedBy": RecoveryPointCreatorTypeDef,
+        "ResourceType": str,
+    },
+    total=False,
+)
+
+DescribeCopyJobOutputTypeDef = TypedDict(
+    "DescribeCopyJobOutputTypeDef", {"CopyJob": CopyJobTypeDef}, total=False
+)
+
 DescribeProtectedResourceOutputTypeDef = TypedDict(
     "DescribeProtectedResourceOutputTypeDef",
     {"ResourceArn": str, "ResourceType": str, "LastBackupTime": datetime},
@@ -199,6 +304,7 @@ _OptionalBackupRuleTypeDef = TypedDict(
         "Lifecycle": LifecycleTypeDef,
         "RecoveryPointTags": Dict[str, str],
         "RuleId": str,
+        "CopyActions": List[CopyActionTypeDef],
     },
     total=False,
 )
@@ -263,8 +369,16 @@ GetBackupVaultNotificationsOutputTypeDef = TypedDict(
             Literal[
                 "BACKUP_JOB_STARTED",
                 "BACKUP_JOB_COMPLETED",
+                "BACKUP_JOB_SUCCESSFUL",
+                "BACKUP_JOB_FAILED",
+                "BACKUP_JOB_EXPIRED",
                 "RESTORE_JOB_STARTED",
                 "RESTORE_JOB_COMPLETED",
+                "RESTORE_JOB_SUCCESSFUL",
+                "RESTORE_JOB_FAILED",
+                "COPY_JOB_STARTED",
+                "COPY_JOB_SUCCESSFUL",
+                "COPY_JOB_FAILED",
                 "RECOVERY_POINT_MODIFIED",
                 "BACKUP_PLAN_CREATED",
                 "BACKUP_PLAN_MODIFIED",
@@ -393,6 +507,10 @@ ListBackupVaultsOutputTypeDef = TypedDict(
     total=False,
 )
 
+ListCopyJobsOutputTypeDef = TypedDict(
+    "ListCopyJobsOutputTypeDef", {"CopyJobs": List[CopyJobTypeDef], "NextToken": str}, total=False
+)
+
 ProtectedResourceTypeDef = TypedDict(
     "ProtectedResourceTypeDef",
     {"ResourceArn": str, "ResourceType": str, "LastBackupTime": datetime},
@@ -487,6 +605,10 @@ StartBackupJobOutputTypeDef = TypedDict(
     total=False,
 )
 
+StartCopyJobOutputTypeDef = TypedDict(
+    "StartCopyJobOutputTypeDef", {"CopyJobId": str, "CreationDate": datetime}, total=False
+)
+
 StartRestoreJobOutputTypeDef = TypedDict(
     "StartRestoreJobOutputTypeDef", {"RestoreJobId": str}, total=False
 )
